'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ZuicoolToast = require('../components/ZuicoolToast');

var _ZuicoolToast2 = _interopRequireDefault(_ZuicoolToast);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var $vm = void 0; /**
                   * Created by LiH on 2018/8/21.
                   */

var timeStamp = void 0;
var fadeOutDuration = 500;

function debounce(duration, fn) {
  timeStamp = Date.now();
  return setTimeout(function () {
    var interval = Date.now() - timeStamp;

    if (interval >= duration) {
      fn();
    }
  }, duration);
}

exports.default = {
  install: function install(Vue) {
    var Toast = Vue.extend(_ZuicoolToast2.default);

    if (!$vm) {
      $vm = new Toast({
        el: document.createElement('div')
      });

      document.body.appendChild($vm.$el);
    }

    Vue.prototype.$ZCToast = Vue.$ZCToast = {
      _debounceTimeout: null,
      _animationTimeout: null,

      _resetStyle: function _resetStyle() {
        $vm.$el.style.transition = '';
        $vm.$el.style.opacity = '1';
      },
      _fadeOut: function _fadeOut() {
        var duration = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 500;

        $vm.$el.style.transition = 'opacity ' + duration / 1000 + 's';
        $vm.$el.style.opacity = '0';
      },
      _clearTimeout: function _clearTimeout(timeout) {
        if (!!this[timeout]) {
          clearTimeout(this[timeout]);
          this[timeout] = null;
        }
      },
      _setPosition: function _setPosition(position) {
        switch (position) {
          case 'top':
            $vm.$el.style.top = '15%';
            break;
          case 'bottom':
            $vm.$el.style.top = '85%';
            break;
          default:
            $vm.$el.style.top = '50%';
        }
      },
      show: function show(conf) {
        var _this = this;

        var content = void 0,
            duration = 2,
            position = 'middle';

        if (String(conf) === '[object Object]') {
          content = conf.content;
          duration = conf.duration;
          position = conf.position;
        } else if (typeof conf === 'string') {
          content = conf;
        } else {
          throw new TypeError('invalid params');
        }

        timeStamp = Date.now();
        this._resetStyle();
        this._setPosition(position);
        $vm.content = content;
        $vm.visible = true;
        this._debounceTimeout = debounce(duration * 1000, function () {
          _this._fadeOut(fadeOutDuration);
          _this._animationTimeout = setTimeout(function () {
            if (Date.now() - timeStamp >= fadeOutDuration) {
              $vm.visible = false;
            }
          }, 500);
        });
      },
      hide: function hide() {
        this._clearTimeout('_debounceTimeout');
        this._clearTimeout('_animationTimeout');
        $vm.visible = false;
      }
    };

    Vue.mixin({
      created: function created() {
        this.$ZCToast = Vue.$ZCToast;
      }
    });
  }
};