'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.request = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _ZCLoading = require('./ZCLoading');

var _ZCLoading2 = _interopRequireDefault(_ZCLoading);

var _ZCAlert = require('./ZCAlert');

var _ZCAlert2 = _interopRequireDefault(_ZCAlert);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var HOST = 'http://' + window.location.host + '/'; /**
                                                    * Created by LiH on 2018/7/19.
                                                    */

var request = _axios2.default.create({ baseURL: HOST });

request.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8';

function handleRequestError(error) {
  // Do something with request error
  console.error('request error:\n' + error.message);
  return _promise2.default.reject(error);
}

function handleResponseError(error) {
  // Do something with response error
  if (_axios2.default.isCancel(error)) {
    console.log('Request canceled', error.message);
  } else if (error.response) {
    // The request was made and the server responded with a status code
    // that falls out of the range of 2xx
    Vue.$ZCAlert.show({
      title: error.response.status === 500 ? '服务器错误' : '网络错误',
      content: error.response.status + ':' + error.response.statusText
    });
    //console.error(error.response.headers)
  } else if (error.request) {
    // The request was made but no response was received
    // `error.request` is an instance of XMLHttpRequest in the browser and an instance of
    // http.ClientRequest in node.js
    Vue.$ZCAlert.show({
      title: '服务器无响应',
      content: ''
    });
    console.error(error.request);
  } else {
    // Something happened in setting up the request that triggered an Error
    console.error('Set up request:\n' + error.message);
  }
  return _promise2.default.reject(error);
}

// 请求计数，用于loading显示控制
var requestCount = 0;

/*
 * 带loading的请求
 */
request.interceptors.request.use(function (config) {
  // Do something before request is sent
  if (config.loading) {
    ++requestCount;
    console.log('requestCount:', requestCount);
    requestCount === 1 && Vue.$ZCLoading.show({
      wxLoading: true,
      desc: '努力加载中……'
    });
  }
  return config;
}, handleRequestError);

function closeLoading() {
  --requestCount;
  if (requestCount <= 0) {
    requestCount = 0;
    Vue.$ZCLoading.hide();
    console.log('requestCount:', requestCount);
  }
}

request.interceptors.response.use(function (response) {
  // Do something with response data
  closeLoading();
  return response;
}, function (error) {
  // Do something with response error
  closeLoading();
  return handleResponseError(error);
});

exports.default = {
  install: function install(Vue, options) {
    if (!Vue.$ZCLoading) {
      Vue.use(_ZCLoading2.default);
    }

    if (!Vue.ZCAlert) {
      Vue.use(_ZCAlert2.default);
    }

    if (options && options.HOST) {
      request.defaults.baseURL = options.HOST;
    }

    Vue.prototype.$requestWithLoading = Vue.prototype.$request = request;
    Vue.$requestWithLoading = Vue.$request = request;
    Vue.mixin({
      created: function created() {
        this.$requestWithLoading = this.$request = request;
      }
    });
  }
};
exports.request = request;